@{
    # Script module or binary module file associated with this manifest.
    RootModule           = 'SqlServerDsc.psm1'

    # Version number of this module.
    ModuleVersion        = '16.6.0'

    # ID used to uniquely identify this module
    GUID                 = '693ee082-ed36-45a7-b490-88b07c86b42f'

    # Author of this module
    Author               = 'DSC Community'

    # Company or vendor of this module
    CompanyName          = 'DSC Community'

    # Copyright statement for this module
    Copyright            = 'Copyright the DSC Community contributors. All rights reserved.'

    # Description of the functionality provided by this module
    Description          = 'Module with DSC resources for deployment and configuration of Microsoft SQL Server.'

    # Minimum version of the Windows PowerShell engine required by this module
    PowerShellVersion    = '5.0'

    # Minimum version of the common language runtime (CLR) required by this module
    CLRVersion           = '4.0'

    # Functions to export from this module
    FunctionsToExport    = @('Add-SqlDscNode','Add-SqlDscTraceFlag','Complete-SqlDscFailoverCluster','Complete-SqlDscImage','Connect-SqlDscDatabaseEngine','ConvertFrom-SqlDscDatabasePermission','ConvertFrom-SqlDscServerPermission','ConvertTo-SqlDscDatabasePermission','ConvertTo-SqlDscServerPermission','Disable-SqlDscAudit','Disconnect-SqlDscDatabaseEngine','Enable-SqlDscAudit','Get-SqlDscAudit','Get-SqlDscConfigurationOption','Get-SqlDscDatabasePermission','Get-SqlDscManagedComputer','Get-SqlDscManagedComputerService','Get-SqlDscPreferredModule','Get-SqlDscServerPermission','Get-SqlDscStartupParameter','Get-SqlDscTraceFlag','Import-SqlDscPreferredModule','Initialize-SqlDscRebuildDatabase','Install-SqlDscServer','Invoke-SqlDscQuery','New-SqlDscAudit','Remove-SqlDscAudit','Remove-SqlDscNode','Remove-SqlDscTraceFlag','Repair-SqlDscServer','Save-SqlDscSqlServerMediaFile','Set-SqlDscAudit','Set-SqlDscDatabasePermission','Set-SqlDscServerPermission','Set-SqlDscStartupParameter','Set-SqlDscTraceFlag','Test-SqlDscIsDatabasePrincipal','Test-SqlDscIsLogin','Test-SqlDscIsSupportedFeature','Uninstall-SqlDscServer')

    # Cmdlets to export from this module
    CmdletsToExport      = @()

    # Variables to export from this module
    VariablesToExport    = @()

    # Aliases to export from this module
    AliasesToExport      = @()

    DscResourcesToExport = @('SqlAudit','SqlDatabasePermission','SqlPermission','SqlAG','SqlAGDatabase','SqlAgentAlert','SqlAgentFailsafe','SqlAgentOperator','SqlAGListener','SqlAGReplica','SqlAlias','SqlAlwaysOnService','SqlConfiguration','SqlDatabase','SqlDatabaseDefaultLocation','SqlDatabaseMail','SqlDatabaseObjectPermission','SqlDatabaseRole','SqlDatabaseUser','SqlEndpoint','SqlEndpointPermission','SqlLogin','SqlMaxDop','SqlMemory','SqlProtocol','SqlProtocolTcpIp','SqlReplication','SqlRole','SqlRS','SqlRSSetup','SqlScript','SqlScriptQuery','SqlSecureConnection','SqlServiceAccount','SqlSetup','SqlTraceFlag','SqlWaitForAG','SqlWindowsFirewall')

    RequiredAssemblies   = @()

    # Private data to pass to the module specified in RootModule/ModuleToProcess. This may also contain a PSData hashtable with additional module metadata used by PowerShell.
    PrivateData          = @{

        PSData = @{
            # Set to a prerelease string value if the release should be a prerelease.
            Prerelease   = ''

            # Tags applied to this module. These help with module discovery in online galleries.
            Tags         = @('DesiredStateConfiguration', 'DSC', 'DSCResourceKit', 'DSCResource')

            # A URL to the license for this module.
            LicenseUri   = 'https://github.com/dsccommunity/SqlServerDsc/blob/main/LICENSE'

            # A URL to the main website for this project.
            ProjectUri   = 'https://github.com/dsccommunity/SqlServerDsc'

            # A URL to an icon representing this module.
            IconUri      = 'https://dsccommunity.org/images/DSC_Logo_300p.png'

            # ReleaseNotes of this module
            ReleaseNotes = '## [16.6.0] - 2024-05-16

### Added

- SqlServerDsc
  - Added build tasks to generate Wiki documentation for public commands.
  - Initial integration tests for commands.
- SqlDatabaseMail
  - Added the parameter `UseDefaultCredentials` to control use of the DatabaseEngine
    service account for SMTP server authentication.
- New public commands
  - `Save-SqlDscSqlServerMediaFile` - Downloads the content on the provided URL
    and if it is an executable it will use the executable to download the
    ISO image media.

### Fixed

- SqlServerDsc
  - `Get-SMOModuleCalculatedVersion`
    - Return SQLPS version as 12.0 instead of 120
  - `Get-SqlDscPreferredModule`
    - Fix sort to get the latest version
  - Public commands no handles when both `-Force` and `-Confirm $true`
    would be passed to command.
  - Enabled NUnit results for HQRM tests.
- `Assert-Feature`
  - Fixed unit tests.
- SqlAGReplica
  - Fix unit test FailedRemoveAvailabilityGroupReplica
- SqlAgentOperator
  - Integration test for changing e-mail address on an existing operator.
- `DatabasePermission`
  - New method ToString() for making verbose output better.
- `ServerPermission`
  - New method ToString() for making verbose output better.
- SqlAgDatabase
  - Remove unused help file ([issue #1745](https://github.com/dsccommunity/SqlServerDsc/issues/1745)).
- SqlDatabaseObjectPermission
  - Added `foreach` loop in `Get-TargetResource` to fix issues with `INSERT`
    permissions when it''s not the only permission on the table ([issue [#2006](https://github.com/dsccommunity/SqlServerDsc/issues/2006)]).
- `Install-SqlDscServer`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Add-SqlDscNode`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Complete-SqlDscFailoverCluster`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Complete-SqlDscImage`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Initialize-SqlDscRebuildDatabase`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Remove-SqlDscNode`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Repair-SqlDscServer`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- `Uninstall-SqlDscServer`
  - No longer throws with duplicate parameter error if the parameter
    `ErrorAction` is passed to the command.
- Private functions
  - `Invoke-SetupAction` no longer throws when secure strings is passed on
    Windows PowerShell.

### Changed

- SqlServerDsc
  - Updated pipeline files to support pre-releases with ModuleFast (when
    resolving dependencies).
  - Bump PSResourceGet to v1.0.0 (used when resolving dependencies).
  - Update markdown highlights with newly supported keywords.
  - Bump GitHub Action _Stale_ to v9.
  - Bump GitHub Action _CodeQL-Action_ to v3.
  - Documentation is now built using a separate meta task `docs`.
    It is run with the meta task `pack` which is run by the pipeline.
    To run the meta task `docs` the SMO assemblies must be loaded into the
    session, either by importing SqlServer module or loading SMO stubs.
  - QA test improved to speed up quality testing.
  - The pipeline test stages has been split into different stages.
- SqlAG
  - Converted unit test to Pester 5
  - DtcSupportEnabled option in Set-TargetResource and TestTargetResource
- SqlSetup
  - Updated integration tests to use PSResourceGet to download required modules.
- SqlRS
  - Integration tests for SQL Server 2022 has been temporarily disabled due
    to a unknown problem. More information in [issue #2009](https://github.com/dsccommunity/SqlServerDsc/issues/2009).

'

        } # End of PSData hashtable

    } # End of PrivateData hashtable
}
